"use strict";
const fakeLightBulbState_enum_1 = require("./fakeLightBulbState.enum");
let hap;
class FakeLightBulb {
    constructor(log, config, api) {
        this.lightBulbState = fakeLightBulbState_enum_1.BulbState.off;
        this.lightBulbBrightness = fakeLightBulbState_enum_1.BulbState.off;
        this.handleOnGet = (callback) => {
            this.log.info("Current state of the bulb was returned: " + (this.lightBulbState ? fakeLightBulbState_enum_1.BulbState.on : fakeLightBulbState_enum_1.BulbState.off));
            callback(undefined, this.lightBulbState);
        };
        this.handleOnSet = (value, callback) => {
            this.lightBulbState = value;
            this.log.info("Bulb state was set to: " + (this.lightBulbState ? fakeLightBulbState_enum_1.BulbState.on : fakeLightBulbState_enum_1.BulbState.off));
            callback();
        };
        this.handleOnGetBrightness = (callback) => {
            this.log.info("Current brightness of the bulb was returned: " + this.lightBulbBrightness);
            callback(undefined, this.lightBulbBrightness);
        };
        this.handleOnSetBrightness = (value, callback) => {
            this.lightBulbBrightness = value;
            this.log.info("Bulb brightness was set to: " + this.lightBulbBrightness);
            callback();
        };
        this.log = log;
        this.name = config.name;
        this.api = api;
        this.lightBulbService = new hap.Service.Lightbulb;
        this.informationService = new hap.Service.AccessoryInformation()
            .setCharacteristic(hap.Characteristic.Manufacturer, "DMNK")
            .setCharacteristic(hap.Characteristic.SerialNumber, "XD")
            .setCharacteristic(hap.Characteristic.Model, "Fake Light Bulb");
        this.lightBulbService.getCharacteristic(this.api.hap.Characteristic.On)
            .on("get" /* GET */, this.handleOnGet)
            .on("set" /* SET */, this.handleOnSet);
        if (config.brightness) {
            this.lightBulbService.getCharacteristic(this.api.hap.Characteristic.Brightness)
                .on("get" /* GET */, this.handleOnGetBrightness)
                .on("set" /* SET */, this.handleOnSetBrightness);
        }
        log.info("Fake Bulb finished initializing!");
    }
    getServices() {
        return [
            this.lightBulbService,
            this.informationService,
        ];
    }
}
module.exports = (api) => {
    hap = api.hap;
    api.registerAccessory("homebridge-fake-light-bulb", FakeLightBulb);
};
//# sourceMappingURL=fakeLightbulbAccesory.js.map